#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date : 12/03/2020

import vmp

PluginName="JrpForensics"

class Plugin(PluginInterfaceType):
  def __init__(self,data,options):
    plugin.PluginInterface.__init__(self,data,options)
    #other operations

  #Interface functions redefinition

class PluginTopic(PluginInterfaceTopicType):
  def __init__(self,modname,plugname):
    plugin.PluginInterfaceTopic.__init__(self,modname,plugname)
    #set the fields of the topic

